@@ -1,6 +1,7 @@
 """:module:`pydantic` models used in this project"""
 from pydantic import BaseModel
 
+
 class WebSocketEventMessage(BaseModel):
     """
     BaseModel of an incoming WebSocketEvent
@@ -12,8 +13,9 @@ class WebSocketEventMessage(BaseModel):
 
     So basically this whole class is kind of pointless.
     """
+
     type: str
 
     class Config:
         use_enum_values = True
-        extra = 'allow'
+        extra = "allow"
